Name:           autofs
Version:        5.0.7
Release:        %mkrel 4
License:        GPLv2+
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            ftp://ftp.kernel.org/pub/linux/daemons/autofs
Source0:        ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.bz2
Patch0:		autofs-5.0.6-fix-libtirpc-name-clash.patch
Patch102:       autofs-5.0.6-separate-config-files.patch
Patch103:       autofs-5.0.4-rename-configuration-file.patch
Patch104:	autofs-5.0.7-do-not-install-init.patch
Patch105:	autofs-5.0.7-after-nss-lookup.patch
BuildRequires:  openldap-devel
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libsasl-devel
BuildRequires:  krb-devel
BuildRequires:  libxml2-devel
BuildRequires:  tirpc-devel
Conflicts:      autosmb
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q -n %{name}-%{version}
%patch0 -R -p1
%patch102 -p1
%patch103 -p1
%patch104 -p0
%patch105 -p1

%build
autoreconf -f -i
%serverbuild
%configure2_5x \
    --with-mapdir=%{_sysconfdir}/%{name} \
    --with-confdir=%{_sysconfdir}/%{name} \
    --with-sasl=yes \
    --disable-mount-locking \
    --enable-ignore-busy \
    --with-libtirpc \
    --disable-mount-move \
    --with-systemd
%make DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}

%make install INSTALLROOT=%{buildroot}

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 samples/autofs.service %{buildroot}%{_unitdir}/autofs.service

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name}
rm -f %{buildroot}%{_mandir}/man8/autofs*

cat > README.urpmi <<EOF
Mageia RPM specific notes

setup
-----
Configuration handling in Mageia package differs from upstream one on several
points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

# tune default configuration
perl -pi -e 's|^BROWSE_MODE="no"|BROWSE_MODE="yes"|' \
    %{buildroot}%{_sysconfdir}/autofs/autofs.conf
perl -pi \
    -e 's|^/misc\t|#/misc\t|;' \
    -e 's|^/net\t|#/net\t|;' \
    %{buildroot}%{_sysconfdir}/autofs/auto.master

%post
%_post_service autofs

%preun
%_preun_service autofs

%files
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%config(noreplace) %{_sysconfdir}/sysconfig/autofs
%{_unitdir}/autofs.service
%{_libdir}/%{name}
%{_sbindir}/automount
%{_mandir}/*/*


%changelog

* Fri Jan 11 2013 umeabot <umeabot> 5.0.7-4.mga3
+ Revision: 346641
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 12 2012 luigiwalser <luigiwalser> 5.0.7-3.mga3
+ Revision: 280947
- fix service ordering when automounter maps are not in local files

* Mon Jul 30 2012 luigiwalser <luigiwalser> 5.0.7-2.mga3
+ Revision: 276225
- revert upstream change deleting tirpc symbol (mga #6903)

* Sun Jul 29 2012 luigiwalser <luigiwalser> 5.0.7-1.mga3
+ Revision: 275730
- no longer install SysV init script
- do not install systemd service file in wrong location (Makefile patch)
- 5.0.7

* Wed May 09 2012 pterjan <pterjan> 5.0.6-6.mga2
+ Revision: 234954
- Fix initscript's LSB header
- Fix License tag

* Sat Apr 28 2012 tmb <tmb> 5.0.6-5.mga2
+ Revision: 233592
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 5.0.6-4.mga2
+ Revision: 233498
- rebuild for versioned rpm-helper requires

* Tue Jan 17 2012 guillomovitch <guillomovitch> 5.0.6-3.mga2
+ Revision: 197345
- sync patches with fedora
- systemd support

* Thu Dec 29 2011 supp <supp> 5.0.6-2.mga2
+ Revision: 188759
- rebuild for mga2

  + guillomovitch <guillomovitch>
    - add missing LSB headers to the init script
    - new version
    - drop obsoletes 4->5 transition post scripts
    - spec cleanup

* Tue Feb 08 2011 ennael <ennael> 5.0.5-4.mga1
+ Revision: 49039
- imported package autofs

